pub struct SimpleWriter<W>(pub W);Expand description
An encode::Writer that simply delegates to an io::Writer and relies
on the default implementations of encode::Writer methods.
Tuple Fields
0: WTrait Implementations
Sourceimpl<W: Clone> Clone for SimpleWriter<W>
impl<W: Clone> Clone for SimpleWriter<W>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<W: Debug> Debug for SimpleWriter<W>
impl<W: Debug> Debug for SimpleWriter<W>
Sourceimpl<W: Hash> Hash for SimpleWriter<W>
impl<W: Hash> Hash for SimpleWriter<W>
Sourceimpl<W: PartialEq> PartialEq for SimpleWriter<W>
impl<W: PartialEq> PartialEq for SimpleWriter<W>
Sourceimpl<W: Write> Write for SimpleWriter<W>
impl<W: Write> Write for SimpleWriter<W>
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Writes a buffer into this writer, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
Sourcefn write_all(&mut self, buf: &[u8]) -> Result<()>
fn write_all(&mut self, buf: &[u8]) -> Result<()>
Attempts to write an entire buffer into this writer. Read more
Sourcefn write_fmt(&mut self, fmt: Arguments<'_>) -> Result<()>
fn write_fmt(&mut self, fmt: Arguments<'_>) -> Result<()>
Writes a formatted string into this writer, returning any error
encountered. Read more
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)Sourceimpl<W: Write> Write for SimpleWriter<W>
impl<W: Write> Write for SimpleWriter<W>
impl<W: Eq> Eq for SimpleWriter<W>
impl<W> StructuralPartialEq for SimpleWriter<W>